/*
 * Bloglines Notifier for Dashboard
 * by Joe Hughes (joe@retrovirus.com) and Jeremy Koempel (jeremy@smalltransport.com)
 */

var req;
var unread = -1;
var updateFrequency = 5 * 60000; // every 5 minutes (but only when Dashboard is visible)
var email = '';
var bloglinesURL = 'http://bloglines.com/myblogs';

var debugEnabled = false;	 
var refreshInterval;

// Utility function for debugging.  When in Dashboard, alerts go to console.

function debug(text) {	 
    if (debugEnabled) {	 
        alert(text);	 
    }	 
}

// Go to the site--different if you're testing in a browser vs. in Dashboard.

function gotoBloglines() {
	if (window.widget) {
		widget.openURL(bloglinesURL);
	} else {
		window.location.href = bloglinesURL;
	}
}

// Creates an instance-specific version of a key for persistent
// Dashboard state storage.

function createkey(key)
{
	return widget.identifier + "-" + key;
}

// If Enter key is pressed on the flip side, flip back to front.

function handleEnter() {
    var keyCode = event.keyCode ? event.keyCode : event.which ? event.which : event.charCode;
    if (keyCode == 13) {
        hidePrefs();
    }
}

// Button states are both in the same image, and are swapped by changing
// the clipping area.  Call pressButton(element ID) when a button is pressed,
// and releaseButton(element ID) when it's released.

function pressButton(id) {
    document.getElementById(id).style.backgroundPosition = '0px -21px'; 
}

function releaseButton(id) {
    document.getElementById(id).style.backgroundPosition = '0px 0px'; 
}

// Perform the flip from front to back.

function showPrefs()
{
	var front = document.getElementById("front");
	var back = document.getElementById("back");
	
	if (window.widget)
		widget.prepareForTransition("ToBack");		// freezes the widget so that you can change it without the user noticing
	
	front.style.display="none";		// hide the front
	back.style.display="block";		// show the back
	
	txt = document.getElementById("emailField");
    txt.focus();  // so you can start typing right away
	
	if (window.widget)
		setTimeout ('widget.performTransition();', 0);	// and flip the widget over	
}

// Perform the flip from back to front, refresh content under the assumption
// that the configuration has changed.

function hidePrefs()
{
	var front = document.getElementById("front");
	var back = document.getElementById("back");
	
	if (window.widget)
		widget.prepareForTransition("ToFront");		// freezes the widget and prepares it for the flip back to the front
	
	back.style.display="none";			// hide the back
	front.style.display="block";		// show the front
	
	txt = document.getElementById("emailField");
	email = txt.value;
	
	if (window.widget) {
        widget.setPreferenceForKey(email, createkey("email")); // save value
    }
	
	refreshCount();
	
	if (window.widget)
		setTimeout ('widget.performTransition();', 0);		// and flip the widget back to the front
}

// Extract the number of unread posts from the very simple Bloglines API format.

function parseResponse(text) {
    return parseInt(text.split('|')[1])
}

// Called when the XMLHttpRequest status changes--if it's got a successful
// response, we update the display with the new value.

function processReqChange() {
    if ((req.readyState == 4) && (req.status == 200)) {
        unread = parseResponse(req.responseText);
        updateDisplay();
    }
}

// Start the process of updating the unread count.

function refreshCount() {
    if (window.widget) {	 
        debug('refreshing content')	 
    }
    
    if (!email || (email.length == 0)) {
        if (window.widget) {
            debug('no email, not refreshing');
            return;
        }
    }
    
    req = new XMLHttpRequest();
    req.open("GET", "http://rpc.bloglines.com/update?user=" + email + "&ver=1&time=" + (new Date).getTime(), true);
    req.onreadystatechange = processReqChange;
    req.send(null);
}

// Update the HTML content for the unread count based on the unread variable.

function updateDisplay() {
    if (window.widget) {	 
        debug('updating display to reflect ' + unread + ' unread');	 
    }
    
    countdiv = document.getElementById("count");
    
    var unreadtext = "" + unread;
    if (unread < 0) {
        unreadtext = "error";
    }
    countdiv.innerHTML = unreadtext;
}

// We don't want the widget refreshing when it's not on the screen, so these
// functions start and stop the refresh timer.

function setRefreshTimer() {	 
    if (refreshInterval == null) {	 
        debug("setting refresh timer");	 
        refreshInterval = setInterval("refreshCount();", updateFrequency);	 
    }	 
}	 
 	 
function clearRefreshTimer() {	 
    if (refreshInterval != null) {	 
        debug("clearing refresh timer");	 
        clearInterval(refreshInterval);	 
        refreshInterval = null;
    }
}
 
function isEmailValid() {
    return (email && (email.length > 0));
}

              
function init() {
    // Attempt to retrieve saved configuration.
    if (window.widget) {
        email = widget.preferenceForKey(createkey("email"));
        if (!email || (email == "undefined")) {
            email = "";
        }
    }
    
	txt = document.getElementById("emailField");
	txt.value = email;

    if (window.widget) {	 
        widget.onshow = function OnShow() { // when Dashboard triggered	 
            debug("widget shown");	 
            setRefreshTimer();	 
            refreshCount();	 
        }	 
        widget.onremove = function OnRemove() { // when widget discarded 
            debug("widget removed");
            widget.setPreferenceForKey(null, createkey("email"));	 
            clearRefreshTimer();	 
        }	 
        widget.onhide = function OnHide() { // when Dashboard dismissed	 
            debug("widget hidden");	 
            clearRefreshTimer();	 
        }	 
    }	 
 	
    setRefreshTimer();
    
    if (!isEmailValid()) { // go directly to config if necessary
        setTimeout ('showPrefs();', 1000); // don't interfere with ripples
    } else {
        refreshCount();
    }	 
}
